const HtmlWebpackPlugin = require('html-webpack-plugin')
const template = require('lodash/template')
const pick = require('lodash/pick')
const readFile = (pathToFile) => require('fs').readFileSync(pathToFile).toString()
const join = require('path').join

module.exports = exports = {
  minifiedPlugin (options = {}) {
    return new HtmlWebpackPlugin({
      templateContent: (args) => exports.baseTemplate({
        ...pick(process.env, 'SEGMENT_KEY', 'STRIPE_PUBLISHABLE_KEY', 'OLARK_SITE_ID'),
        ...args,
      }),
      filename: 'index.html',
      minify: {
        removeComments: true,
        collapseWhitespace: true,
        removeRedundantAttributes: true,
        useShortDoctype: true,
        removeEmptyAttributes: true,
        removeStyleLinkTypeAttributes: true,
        keepClosingSlash: true,
        minifyJS: true,
        minifyCSS: true,
        minifyURLs: true,
      },
      ...options,
    })
  },

  basePlugin (options = {}) {
    return new HtmlWebpackPlugin({
      filename: 'index.html',
      templateContent: (args) => exports.baseTemplate({
        ...pick(process.env, 'SEGMENT_KEY', 'STRIPE_PUBLISHABLE_KEY', 'OLARK_SITE_ID'),
        ...args,
      }),
      ...options,
    })
  },

  get baseTemplate() {
    return exports.createTemplateFromFile(
      join(process.cwd(), 'src', 'base.html')
    )
  },

  createTemplateFromFile (pathToFile) {
    const content = readFile(pathToFile)
    return template(content)
  },
}
