jest.dontMock('../PhoneInput');

import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';

const PhoneInput = require('../PhoneInput').default;
const callback = jest.genMockFn();

describe('PhoneInput lifecycle tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<PhoneInput onStateUpdate={callback}/>);
    input = component.refs.ccPhoneInput;
  });

  it('renders properly on load', () => {
    // Should exist
    expect(input).toBeTruthy();
    // Should be empty
    expect(input.textContent).toBe('');
  });

  it('calls props.onStateUpdate to change outer state', () => {
    // Set a new value
    input.value = '9119119111';

    // Change it
    TestUtils.Simulate.change(input);

    // Check it
    expect(callback).toBeCalled();
  });

  it('handles onPaste properly', () => {
    component._reformatInput = jest.genMockFn();

    // Set a new value
    input.value = '9119119111';

    // Change it
    TestUtils.Simulate.paste(input);

    // Check it
    expect(component._reformatInput).toBeCalled();
  });

  it('handles onKeyPress properly', () => {
    component._restrictInput = jest.genMockFn();

    // Trigger
    TestUtils.Simulate.keyPress(input, {keyCode: 52});

    // Check it
    expect(component._restrictInput).toBeCalled();
  });
});

describe('PhoneInput formatter/validator tests', () => {
  let component;
  let input;

  beforeEach(() => {
    component = TestUtils.renderIntoDocument(<PhoneInput onStateUpdate={callback}/>);
    input = component.refs.ccPhoneInput;
  });

  it('ensures restrictPhone disallows letter input', () => {
    // Set up a dummy event
    const event = {
      keyCode: 65,
      which: 65,
      target: {value: ''},
      preventDefault: jest.genMockFn()
    };

    const result = component._restrictInput(event);
    expect(result).toBeUndefined();
  });

  it('ensures restrictPhone restricts over 20 digit input', () => {
    // Set up a dummy event
    const event = {
      keyCode: 55,
      which: 55,
      target: {value: '12345678901234567890'},
      preventDefault: jest.genMockFn()
    };

    const result = component._restrictInput(event);
    expect(event.preventDefault).toBeCalled();
  });
});
