import React from 'react';
import pull from 'lodash/pull';
import map from 'lodash/map';
import includes from 'lodash/includes';
import isArray from 'lodash/isArray';
import classnames from 'classnames';

class FilterTags extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      query: ''
    };
  }

  toggleChip(filterChip, e) {
    const { selected, sources } = this.props;
    const sourceId = filterChip.id.id;

    // TODO refactor to immutable set
    if (selected.includes(sourceId)) {
      pull(selected, sourceId);
    } else {
      selected.push(sourceId);
    }
    filterChip.onChange(selected);
  }

  createChip(filterChip, index) {
    return (
      <button
        key={index}
        className={classnames({'is-active': filterChip.isSelected})}
        onClick={(e) => this.toggleChip(filterChip, e)}
      >
        {filterChip.name}
      </button>
    );
  }

  handleOnChange(e) {
    const query = e.target.value;
    this.setState({query});
  }

  renderChips(filterTags) {
    return map(filterTags, (filterChip, index) => this.createChip(filterChip, index));
  }

  render() {
    const { getName, onChange, selected, sources } = this.props;

    let filterTags = map(sources, (id) => ({
      id,
      name: getName(id),
      isSelected: includes(selected, id.id),
      onChange
    }));

    filterTags = filterTags.filter(tag => {
      const regex = new RegExp(this.state.query, 'i');
      return tag.name.match(regex);
    });

    return (
      <div className="FilterTags">
        <div className="FilterTags-tags">
          {this.renderChips(filterTags)}
        </div>
      </div>
    );
  }
}

FilterTags.propTypes = {
  // defines what the property name of this filter is
  filterType: React.PropTypes.string.isRequired,

  // Returns a string to display to represent the item
  getName: React.PropTypes.func.isRequired,

  // A callback that is passed a modified selected
  onChange: React.PropTypes.func.isRequired,

  // A list of identifiers for sources that are selected
  selected: React.PropTypes.array.isRequired,

  // Things that we need checkboxes for
  sources: React.PropTypes.any.isRequired,
};

export default FilterTags;

// Search Functionality
//
// <div className="FilterTags-search">
//   <input type="text"
//          placeholder={'Search ' + this.props.filterType + '...'}
//          onChange={(e) => this.handleOnChange(e)}
//   />
// </div>
